Module hash

Module hash 

Content hashing and a small per-run cache.

Structs

DigestCache
Hashes a path once per run.
HashingReader
A reader which records the digest and number of bytes it has yielded.
HashingWriter
A writer which records the digest and number of bytes accepted by its inner writer.

Functions

ensure_matches_plan
Fail when bytes copied from a source no longer match the plan.
sha256_bytes
sha256_file
Hash a file without loading it all at once.