The dependency graph records both what is included and why.
Structs
Enums
Constants
- DIGEST_
LEN_ HEX - Length of a SHA-256 digest in lowercase hexadecimal.
- EDGES_
MAX - Upper bound on edges. Every edge is one
DT_NEEDED,PT_INTERPor policy reason, so this allows an average of 64 dependencies per object. - NODES_
MAX - Upper bound on the objects in one runtime closure.
Type Aliases
- NodeId
- Index of a node in
DependencyGraph::nodes.