Content hashing and a small per-run cache.
Structs
- Digest
Cache - Hashes a path once per run.
- Hashing
Reader - A reader which records the digest and number of bytes it has yielded.
- Hashing
Writer - A writer which records the digest and number of bytes accepted by its inner writer.
Functions
- ensure_
matches_ plan - Fail when bytes copied from a source no longer match the plan.
- sha256_
bytes - sha256_
file - Hash a file without loading it all at once.