HashingReader

Struct HashingReader 

pub struct HashingReader<R> { /* private fields */ }
A reader which records the digest and number of bytes it has yielded.

Output backends use this while copying planned source files so the bytes that were actually written are checked against the immutable plan.

Implementations

Source

impl<R> HashingReader<R>

pub fn new(inner: R) -> HashingReader<R>

pub fn finish(self) -> (Digest, u64)