The source filesystem, abstracted behind --root.
The source root is treated as strictly read-only, and as the logical / of
the target system. Symlinks are followed logically (inside the root) so a
sysroot can be analyzed without any chance of escaping to the host.
Structs
- ElfCache
- Parses each ELF object at most once, keyed by host path.
- Resolved
- A logical path resolved to a real file inside the source root.
- Source
Root - Symlink
Entry - A symlink observed while resolving a logical path.